@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.17_01'; # TRIAL VERSION
+our $VERSION = '1.17_02'; # TRIAL VERSION
 
 
 use 5.006;
@@ -129,7 +129,7 @@ sub _preload_module
   # this is hopefully a pm file that nobody would use
   my $filename = File::Spec->catfile($dir, '__TEST_SCRIPT__.pm');
   my $fh;
-  open($fh, ">$filename") 
+  open($fh, '>', $filename) 
     || die "unable to open $filename: $!";
   print($fh 'unshift @INC, ',
     join ',', 
@@ -284,7 +284,7 @@ sub _perl_args {
   my($script) = @_;
   my $fh;
   my $first_line = '';
-  if(open($fh, "<$script"))
+  if(open($fh, '<', $script))
   {
     $first_line = <$fh>;
     close $fh;
@@ -334,7 +334,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.17_01
+version 1.17_02
 
 =head1 SYNOPSIS
 
